Struct Header

struct Header<'a> { ... }

Represents a parsed header.

Fields

name: &'a str

The name portion of a header.

A header name must be valid ASCII-US, so it's safe to store as a &str.

value: &'a [u8]

The value portion of a header.

While headers should be ASCII-US, the specification allows for values that may not be, and so the value is stored as bytes.

Implementations

impl Debug for Header<'_>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Clone for Header<'a>

fn clone(self: &Self) -> Header<'a>

impl<'a> Copy for Header<'a>

impl<'a> Eq for Header<'a>

impl<'a> Freeze for Header<'a>

impl<'a> PartialEq for Header<'a>

fn eq(self: &Self, other: &Header<'a>) -> bool

impl<'a> RefUnwindSafe for Header<'a>

impl<'a> Send for Header<'a>

impl<'a> StructuralPartialEq for Header<'a>

impl<'a> Sync for Header<'a>

impl<'a> Unpin for Header<'a>

impl<'a> UnsafeUnpin for Header<'a>

impl<'a> UnwindSafe for Header<'a>

impl<T> Any for Header<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Header<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Header<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Header<'a>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Header<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Header<'a>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Header<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Header<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Header<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>