Enum Status
enum Status<T>
The result of a successful parse pass.
Complete is used when the buffer contained the complete value.
Partial is used when parsing did not reach the end of the expected value,
but no invalid data was found.
Variants
-
Complete(T) The completed result.
-
Partial A partial result.
Implementations
impl<T> Status<T>
fn is_complete(self: &Self) -> boolConvenience method to check if status is complete.
fn is_partial(self: &Self) -> boolConvenience method to check if status is partial.
fn unwrap(self: Self) -> TConvenience method to unwrap a Complete value. Panics if the status is
Partial.
impl<T> Any for Status<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Status<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Status<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Status<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Freeze for Status<T>
impl<T> From for Status<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for Status<T>
impl<T> Send for Status<T>
impl<T> StructuralPartialEq for Status<T>
impl<T> Sync for Status<T>
impl<T> ToOwned for Status<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for Status<T>
impl<T> UnsafeUnpin for Status<T>
impl<T> UnwindSafe for Status<T>
impl<T, U> Into for Status<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Status<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Status<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone> Clone for Status<T>
fn clone(self: &Self) -> Status<T>
impl<T: $crate::cmp::Eq> Eq for Status<T>
impl<T: $crate::cmp::PartialEq> PartialEq for Status<T>
fn eq(self: &Self, other: &Status<T>) -> bool
impl<T: $crate::fmt::Debug> Debug for Status<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result