Function parse_headers
fn parse_headers<'b: 'h, 'h>(src: &'b [u8], dst: &'h mut [Header<'b>]) -> Result<(usize, &'h [Header<'b>])>
Parse a buffer of bytes as headers.
The return value, if complete and successful, includes the index of the buffer that parsing stopped at, and a sliced reference to the parsed headers. The length of the slice will be equal to the number of properly parsed headers.
Example
let buf = b"Host: foo.bar\nAccept: */*\n\nblah blah";
let mut headers = ;
assert_eq!;